@@ -428,6 +428,8 @@ cache_check_info_print (int i, sal_log_mod_error_info_t *cache_check_info)
 			info->mesi, info->mesi < ARRAY_SIZE(mesi) ? mesi[info->mesi] : "reserved");
 	if (info->wiv)
 		iprintf(", Way: %d, Index: %d", info->way, info->index);
+	if (info->dp)
+		iprintf(", Data poisoned on MBE");
 	iprintf("\n");
 	mod_error_info_common_print(cache_check_info, info);
 	--indent;
@@ -525,6 +527,8 @@ bus_check_info_print (int i, sal_log_mod_error_info_t *bus_check_info)
 	iprintf(", Type: %d (%s)",
 		info->type, info->type < ARRAY_SIZE(type) ? type[info->type] : "reserved");
 	iprintf(", Severity: %d, Hierarchy: %d", info->sev, info->hier);
+	if (info->dp)
+		iprintf(", Data poisoned on MBE");
 	iprintf(", Status information: %d (%s)",
 		info->bsi, info->bsi < ARRAY_SIZE(bsi) ? bsi[info->bsi] : "processor specific");
 	iprintf("\n");
