@@ -23,6 +23,8 @@
  *                      (plus examples of platform error info structures from smariset @ Intel)
  * 2003-11-05 Strip down to the bare minimum required to decode SAL records.
  *	      Keith Owens <kaos@sgi.com>
+ * 2005-12-14 Correct the definition of the severity code and validation bits.
+ *	      Keith Owens <kaos@sgi.com>
  */
 
 #include "efi.h"
@@ -74,7 +76,8 @@ typedef struct sal_log_timestamp {
 typedef struct sal_log_record_header {
 	u64 id;				/* Unique monotonically increasing ID */
 	sal_log_revision_t revision;	/* Major and Minor revision of header */
-	u16 severity;			/* Error Severity */
+	u8 severity;			/* Error Severity */
+	u8 validation_bits;;		/* Validation Bits */
 	u32 len;			/* Length of this error log in bytes */
 	sal_log_timestamp_t timestamp;	/* Timestamp */
 	efi_guid_t platform_guid;	/* Unique OEM Platform ID */
