@@ -567,6 +567,21 @@ talk_to_sal (void)
 				perror(filename);
 				goto out;
 			}
+			if ((fd = open(filename, O_RDONLY)) >= 0) {
+				sal_log_record_header_t *buffer2;
+				int bufsize2, duplicate;
+				buffer2 = salinfo_buffer(fd, &bufsize2);
+				duplicate = buffer2 &&
+					    bufsize == bufsize2 &&
+					    memcmp(buffer, buffer2, bufsize) == 0;
+				free(buffer2);
+				if (duplicate) {
+					syslog(LOG_NOTICE,
+					       "duplicate record dropped: %s",
+					       basename);
+					goto done;
+				}
+			}
 		}
 
 		for (l = 0; l < bufsize; ) {
@@ -577,7 +592,7 @@ talk_to_sal (void)
 			}
 			l += i;
 		}
-		close(fd);
+		fsync(fd);
 
 		snprintf(filename, sizeof(filename),
 			"%s/decoded/%s", directory, basename);
@@ -595,12 +610,16 @@ talk_to_sal (void)
 		printf("BEGIN HARDWARE ERROR STATE from %s on cpu %d\n", type, cpu);
 		platform_info_print(buffer, 1, fd_data, cpu, oemdata_fd);
 		printf("END HARDWARE ERROR STATE from %s on cpu %d\n", type, cpu);
-		free(buffer);
+		fflush(stdout);
+		fsync(fileno(stdout));
 		fclose(stdout);
-		if (clear_cpu(fd_data, cpu, data_filename, 1))
-			goto out;
 		if (trigger.set)
 			write_trigger(basename);
+done:
+		close(fd);
+		if (clear_cpu(fd_data, cpu, data_filename, 1))
+			goto out;
+		free(buffer);
 	}
 
 out:
